nbxmpp.stringprepare

Package nbxmpp :: Module stringprepare |
[hide private]
[frames] | no frames]

# Module stringprepare

source code

Classes | [hide private]
| ILookupTable Interface for character lookup classes
| IMappingTable Interface for character mapping classes
| LookupTableFromFunction
| LookupTable
| MappingTableFromFunction
| EmptyMappingTable
| Profile
| NamePrep Implements preparation of internationalized domain names

Variables | [hide private]
| C_11 = `LookupTableFromFunction(stringprep.in_table_c11)`
| C_12 = `LookupTableFromFunction(stringprep.in_table_c12)`
| C_21 = `LookupTableFromFunction(stringprep.in_table_c21)`
| C_22 = `LookupTableFromFunction(stringprep.in_table_c22)`
| C_3 = `LookupTableFromFunction(stringprep.in_table_c3)`
| C_4 = `LookupTableFromFunction(stringprep.in_table_c4)`
| C_5 = `LookupTableFromFunction(stringprep.in_table_c5)`
| C_6 = `LookupTableFromFunction(stringprep.in_table_c6)`
| C_7 = `LookupTableFromFunction(stringprep.in_table_c7)`
| C_8 = `LookupTableFromFunction(stringprep.in_table_c8)`
| C_9 = `LookupTableFromFunction(stringprep.in_table_c9)`
| B_1 = `EmptyMappingTable(stringprep.in_table_b1)`
| B_2 = `MappingTableFromFunction(stringprep.map_table_b2)`
| nodeprep = `Profile(mappings= [B_1, B_2], prohibiteds= [C_11, C`...``
| resourceprep = `Profile(mappings= [B_1,], prohibiteds= [C_12, C`...``
| nameprep = `NamePrep()`
| __package__ = ``'``nbxmpp``'``

Imports: stringprep, unicodedata, idna

Variables Details | [hide private]

  ### C_11 Value:
      LookupTableFromFunction(stringprep.in_table_c11)

  ### C_12 Value:
      LookupTableFromFunction(stringprep.in_table_c12)

  ### C_21 Value:
      LookupTableFromFunction(stringprep.in_table_c21)

  ### C_22 Value:
      LookupTableFromFunction(stringprep.in_table_c22)

  ### C_3 Value:
      LookupTableFromFunction(stringprep.in_table_c3)

  ### C_4 Value:
      LookupTableFromFunction(stringprep.in_table_c4)

  ### C_5 Value:
      LookupTableFromFunction(stringprep.in_table_c5)

  ### C_6 Value:
      LookupTableFromFunction(stringprep.in_table_c6)

  ### C_7 Value:
      LookupTableFromFunction(stringprep.in_table_c7)

  ### C_8 Value:
      LookupTableFromFunction(stringprep.in_table_c8)

  ### C_9 Value:
      LookupTableFromFunction(stringprep.in_table_c9)

  ### B_1 Value:
      EmptyMappingTable(stringprep.in_table_b1)

  ### B_2 Value:
      MappingTableFromFunction(stringprep.map_table_b2)

  ### nodeprep Value:
      Profile(mappings= [B_1, B_2], prohibiteds= [C_11, C_12, C_21, C_22, C_
      3, C_4, C_5, C_6, C_7, C_8, C_9, LookupTable([u'"', u'&', u"'", u'/',
      u':', u'<', u'>', u'@'])])

  ### resourceprep Value:
      Profile(mappings= [B_1,], prohibiteds= [C_12, C_21, C_22, C_3, C_4, C_
      5, C_6, C_7, C_8, C_9])

  ### nameprep Value:
      NamePrep()

  ### __package__ Value:
      'nbxmpp'